%{
- Ova skripta sluzi za analizu uticaja variranja sirine i visine vrha 
zupca sinhronog motora sa povrsinski montiranim permanentnim magnetima
na vrednosti valovitosti elektromagnetskog momenta i vrednosti korisnog momenta.
- U okviru skripte poziva se f-ja Proracunmomenta koja vrsi iterativno
pozivanje f-je Redukovanmodel za simulaciju elektromagnetskih procesa
metodom konacnih elemenata u Femm4.2 softveru i vraca vektore sa
vrednostima mehanickog momenta motora i njegove valovitosti.
- Vrednosti pocetnih i krajnih dimenzija sirine i visine vrha zupca zadaju
se za proizvoljnu masinu simuliranu uz pomoc Redukovanmodel.
- Parametri su inicijalno podeseni za sestopolnu masinu sa 18 statorskih 
zlebova, ali se mogu proizvoljno menjati.
- Rezultati simulacije su Table (matrica u kojoj svaka vrsta odgovara paru
sirine i visine vrha zupca motora) i dcTorque (matrica u kojoj svaka vrsta 
predstavlja odgovarajuci talasnog oblika momenta).

S.Subotic

%}


% Ulazni podaci:

Width1 = 3.857;  % pocenta vrednost sirine vrha zubca 
Height1 = 0;     % pocenta vrednost visine vrha zubca 

Kw = 29;  % Zeljeni broj koraka izmedju pocetne i krajne vrednosti sirine. Za vrednost 1 racuna sa samo sa pocentnom i krajnom vrednoscu, za 2 postoji jedna vrednost izmedju itd.
Kh = 29;  % Zeljeni broj koraka izmedju pocetne i krajne vrednosti visine

Width2 = 8.7;  % krajnja vrednost sirine vrha zubca 
Height2 = 5;   % krajnja vrednost visine vrha zubca 

deltaW = (Width2-Width1)/Kw;  % korak sa kojim se inkrementiraju vrednosti Width
deltaH = (Height2-Height1)/Kh;  % korak sa kojim se inkrementiraju vrednosti Height

Table = zeros((Kw+1)*(Kh+1),2);  % matrica u koju se upisuju vrednosti sirine i visine. Sirina je prva kolona, a visina druga 
% Vazno je napomenuti da u matrici dcTorque svaki red  odgovara paru sirine i visine iz odgovarajuceg reda u matrici Table.

a = 0;  % a sluzi za indeksiranje u for petljama

wb = waitbar(0,sprintf('Obradjeno je %i%% (%i/%i) topologija',fix(100*a/((Kw+1)*(Kh+1))),a,(Kw+1)*(Kh+1)),'Name',sprintf('Simulacije u toku'));  % prikaz napretka

for i = Width1:deltaW:Width2
    for j = Height1:deltaH:Height2
    a = a+1;
    Table(a,:) = [i,j];        % tabela sa vrednostima sirine i visine vrha zubca
    A = Proracunmomenta(i,j);
    dcTorque(a,:) = A;         % matrica sa vektorima momenta za odgovarajuci red iz tabele. 
    waitbar(a/((Kw+1)*(Kh+1)),wb,sprintf('Obradjeno je %i%% (%i/%i) topologija',fix(100*a/((Kw+1)*(Kh+1))),a,(Kw+1)*(Kh+1)));  %  azuriranje napretka
    end
end
close(wb);  % zatvaranje prozorcica koji prikazuje napredak