function Motor(Width,Heigth,Theta,C)
%{ 
- Ova skripta sluzi za simulaciju elektromagnetskih procesa u motoru u 
Femm4.2 softveru uz prikaz celokupnog poprecnog preseka masine. 
- Moguce je iscrtati poprecni presek masine proivoljnih dimenzija sa 
proizvoljnim brojem zlebova i pari polova.
- Funkciji se prosledjuju vrednosti sirine i visine vrha zupca motora,
ugao rotora Theta, kao i parmetar C objasnjen u 55. redu koda.
- Za sve povrsi od interesa definisani su odgovarajuci materijali ili
svojstva, kao i neophodni granicni uslovi. Postoji mogucnost zadavanja 
namotaja ili vazduha u statorskom namotaju. 
- Prilikom zadavanja parametara namotaja teba imati u vidu da skripta ne 
podrzava razlomljen broj zlebova po polu i fazi. 
- Parametri skripte su incijalno podeseni za sestopolnu masinu zadatih 
dimenzija sa 18 zlebova na statoru, ali se mogu proizvoljno menjati 
unosenjem odgovarajucih vrednosti u delu Ulazni podaci.
- Kod izmene postojecih i definisanja novih materijala pristupati oprezno,
jer je izmene neophodno uneti na vise mesta.
- Preporucuje se vizuelna provera pokretanjem skripte prilikom unosenja  
svake izmene. 
- Kod je detaljno iskomentarisan

S. Subotic
%}


openfemm        % otvara femm prozor
newdocument(0)  % otvara nov dokument i definise tip problema 
mi_hidegrid;    % uklanja prikaz mreze sa ekrana 


% Ulazni podaci:

% za vrhove zubaca:
statorToothTipWidth    = Width;   % sirina vrha statorskog zupca 
statorToothTipHeigth   = Heigth;  % sisina vrha statorskog zupca 

machineLength		= 70;      % aksijalna duzina motora 
statorSlotsNr       = 18;      % broj statorskih zlebova
statorInnerRadius   = 25.2;    % unutrasnji poluprecnik statora 
statorYokeRadius    = 39.175;  % poluprecnik jezgra statora
statorOuterRadius   = 45;      % spoljasnji poluprecnik motora 
statorToothWidth    = 3.845;   % sirina (tela)zupca statora 
angleFirstCurve     = 75;      % ugao pocetka prvog zaobljenja u odnosu na simetralu zleba (u stepenima)
firstCurveRadius    = 0.7;     % poluprecnik  prvog zaobljenja (kod vrha zupca) 
secondCurveRadius   = 2.75;    % poluprecnik  drugog zaobljenja zupca (ka jezgru)

polePairs           = 3;     % broj pari polova
rotorInnerRadius    = 10.5;  % poluprecnik vratila 
rotorOuterRadius    = 22.7;  % spoljasnji poluprecnik rotora (gde nema magneta)
magnetInnerRadius   = 21.7;  % unutrasnji poloprecnik magneta 
magnetOuterRadius   = 24.5;  % unutrasnji poloprecnik magneta 
magnetAngle         = 51;    % ugao pod kojim se magnet vidi iz sredista motora (u stepenima)

condition1          = C;      % za condition1=1 - vazduh u zlebovima; za bilo koju drugu vrednost - namotaji u zlebovima  
wireTurnsPerSlot    = 35;     % broj navojaka u svakom zlebu
statorMagCurrentEff = 8;      % efektivna vrednost statorske struje


% Iscrtavanje statora:

mi_addnode(statorInnerRadius,0);  % 1. tacka
mi_addnode(statorOuterRadius,0);  % 2. tacka. 
angle1 = 360/(statorSlotsNr*2);   % ugao izmedju centra zleba i centra zuba (u stepenima) 
alpha = 360*statorToothTipWidth/(2*2*statorInnerRadius*pi);  % ugao koji odgovara polovini sirine vrha zupca (u stepenima) 
mi_addnode(statorInnerRadius*cos(alpha*pi/180),statorInnerRadius*sin(alpha*pi/180));  % 3. tacka
mi_addarc(statorInnerRadius,0,statorInnerRadius*cos(alpha*pi/180),statorInnerRadius*sin(alpha*pi/180),alpha,1);
x4 = statorInnerRadius*cos(alpha*pi/180)+statorToothTipHeigth*cos(angle1*pi/180);
y4 = statorInnerRadius*sin(alpha*pi/180)+statorToothTipHeigth*sin(angle1*pi/180);
mi_addnode(x4,y4);  % 4. tacka
mi_addsegment(statorInnerRadius*cos(alpha*pi/180),statorInnerRadius*sin(alpha*pi/180),x4,y4)
x5 = x4+(y4-statorToothWidth/2)/tan((angleFirstCurve-angle1)*pi/180);
y5 = statorToothWidth/2;
mi_addnode(x5,y5);  % 5. tacka
mi_addsegment(x4,y4,x5,y5);
mi_addnode(statorYokeRadius*cos(angle1*pi/180),statorYokeRadius*sin(angle1*pi/180)); % 6. tacka
x7 = statorYokeRadius*cos(angle1*pi/180)+tan(angle1*pi/180)*(statorYokeRadius*sin(angle1*pi/180)- statorToothWidth/2);
y7 = statorToothWidth/2;
mi_addnode(x7,y7);  % 7. tacka
mi_addsegment(statorYokeRadius*cos(angle1*pi/180),statorYokeRadius*sin(angle1*pi/180),x7,y7);
mi_addsegment(x5,y5,x7,y7);
mi_createradius(x5,y5,firstCurveRadius);   % od ugla sa temenom u 5. tacki pravi prvo zaobljenje
mi_createradius(x7,y7,secondCurveRadius);  % od ugla sa temenom u 7. tacki pravi drugo zaobljenje
mi_selectcircle(0,0,statorOuterRadius-0.1,4);
mi_setgroup(1);
mi_selectgroup(1);
mi_mirror2(0,0,statorYokeRadius*cos(angle1*pi/180),statorYokeRadius*sin(angle1*pi/180),4);  % kreira simetricnu sliku izabranih elemenata u odnosu na datu duz
mi_addsegment(x4,y4,(x4+y4*tan(angle1*pi/180))/(1+(tan(angle1*pi/180)^2)),...
x4*tan(angle1*pi/180)+(y4*(tan(angle1*pi/180))^2)/(1+(tan(angle1*pi/180)^2))+0.01);  % linija koja zatvara prostor gde su namotaji.
mi_selectcircle(0,0,statorOuterRadius-0.1,4);
mi_setgroup(2);
mi_selectgroup(2);
mi_copyrotate2(0,0,2*angle1,statorSlotsNr-1,4);  % zarotirano kopira odabrane elemente
mi_addnode(-statorOuterRadius,0);  % 9. tacka
mi_addarc(statorOuterRadius,0,-statorOuterRadius,0,180,1);
mi_addarc(-statorOuterRadius,0,statorOuterRadius,0,180,1); 


% Iscrtavanje rotora:

mi_addnode(rotorOuterRadius,0);  % 10. tacka
x11 = magnetInnerRadius*cos((90/polePairs-magnetAngle/2)*pi/180);
y11 = magnetInnerRadius*sin((90/polePairs-magnetAngle/2)*pi/180);
mi_addnode(x11,y11);  % 11. tacka 
x12 = rotorOuterRadius*cos((90/polePairs-magnetAngle/2)*pi/180);
y12 = rotorOuterRadius*sin((90/polePairs-magnetAngle/2)*pi/180);
mi_addnode(x12,y12);  % 12. tacka
mi_addsegment(x11,y11,x12,y12);
x13 = magnetOuterRadius*cos((90/polePairs-magnetAngle/2)*pi/180);
y13 = magnetOuterRadius*sin((90/polePairs-magnetAngle/2)*pi/180);
mi_addnode(x13,y13);  % 13. tacka 
mi_addsegment(x12,y12,x13,y13);
mi_addarc(rotorOuterRadius,0,x12,y12,90/polePairs-magnetAngle/2,1); 
mi_addsegment(x12,y12,x13,y13);
x14 = magnetInnerRadius*cos(90/polePairs*pi/180);
y14 = magnetInnerRadius*sin(90/polePairs*pi/180);
mi_addnode(x14,y14);  % 14. tacka 
x15 = magnetOuterRadius*cos(90/polePairs*pi/180);
y15 = magnetOuterRadius*sin(90/polePairs*pi/180);
mi_addnode(x15,y15);  % 15. tacka 
mi_addarc(x11,y11,x14,y14,magnetAngle/2,1);
mi_addarc(x13,y13,x15,y15,magnetAngle/2,1);
mi_selectcircle(0,0,magnetOuterRadius+0.01,4);
mi_setgroup(3);
mi_selectgroup(3);
mi_mirror2(0,0,x15,y15,4); 
mi_selectcircle(0,0,magnetOuterRadius+0.01,4);
mi_setgroup(4);
mi_selectgroup(4);
mi_copyrotate2(0,0,180/polePairs,2*polePairs-1,4);
mi_addnode(rotorInnerRadius,0);  % 16. tacka
mi_addnode(-rotorInnerRadius,0)  % 17. tacka 
mi_addarc(rotorInnerRadius,0,-rotorInnerRadius,0,180,1);
mi_addarc(-rotorInnerRadius,0,rotorInnerRadius,0,180,1);
mi_zoomnatural();


% Definisanje problema, materijala, strujnih kola i granicnih uslova:

mi_probdef(0,'millimeters','planar',1e-8,machineLength,30,(0));  % osnovna podesavanja
smartmesh(0);  % gasi smartmesh - NE RADI!!!

mi_getmaterial('NdFeB 32 MGOe'); % uvoz materijala iz Femm biblioteke
mi_getmaterial('1020 Steel');
mi_getmaterial('M-19 Steel');
mi_getmaterial('Air');
mi_getmaterial('16 AWG');

mi_addcircprop('A',statorMagCurrentEff*sqrt(2)*cos((polePairs*Theta+60)*pi/180),1);  % definisanje strujnih kola
mi_addcircprop('B',statorMagCurrentEff*sqrt(2)*cos((polePairs*Theta-60)*pi/180),1);
mi_addcircprop('C',statorMagCurrentEff*sqrt(2)*cos((polePairs*Theta-180)*pi/180),1);
mi_addboundprop('NoNormalFluxAllowed',0,0,0,0,0,0,0,0,0,0,0);  % uvoz granicnih uslova

% materijali za rotor:

mi_addblocklabel(0,0);  % zadaje se kako se ne bi pravio mesh u vratilu
mi_selectlabel(0,0);
mi_setgroup(5);
mi_selectgroup(5);
mi_setblockprop('<No Mesh>', 1, 0, 0, 0, 5, 0);
mi_clearselected();

R1=rotorInnerRadius/2+magnetInnerRadius/2;
mi_addblocklabel(R1*cos((90/polePairs)*pi/180),R1*sin((90/polePairs)*pi/180));  % rotorsko gvozdje
mi_selectlabel(R1*cos((90/polePairs)*pi/180),R1*sin((90/polePairs)*pi/180));
mi_setgroup(6);
mi_selectgroup(6);
mi_setblockprop('1020 Steel', 1, 0, 0, 0, 6, 0);
mi_clearselected();

R2=magnetInnerRadius/2+magnetOuterRadius/2;
mi_addblocklabel(R2*cos((90/polePairs)*pi/180),R2*sin((90/polePairs)*pi/180));  % magnet 1
mi_selectlabel(R2*cos((90/polePairs)*pi/180),R2*sin((90/polePairs)*pi/180));
mi_setgroup(7);
mi_selectgroup(7);
mi_setblockprop('NdFeB 32 MGOe',1,0,0,sprintf('theta+%i',0),7,0);  % radijalno zadavanje smera magnetizacije
mi_clearselected();
mi_selectgroup(7);
mi_copyrotate2(0,0,360/polePairs,polePairs-1,4);
mi_clearselected();

R3=magnetInnerRadius/2+magnetOuterRadius/2;
mi_addblocklabel(R3*cos(270/polePairs*pi/180),R3*sin(270/polePairs*pi/180));  % magnet 2
mi_selectlabel(R3*cos(270/polePairs*pi/180),R3*sin(270/polePairs*pi/180));
mi_setgroup(8);
mi_selectgroup(8);
mi_setblockprop('NdFeB 32 MGOe',1,0,0,sprintf('theta+%i',180),8,0);
mi_clearselected();
mi_selectgroup(8);
mi_copyrotate2(0,0,360/polePairs,polePairs-1,4);
mi_clearselected();

% za vazdusni zazor:

R4=magnetOuterRadius+0.1;
mi_addblocklabel(R4*cos((90/polePairs)*pi/180),R4*sin((90/polePairs)*pi/180));  % vazdusni zazor
mi_selectlabel(R4*cos((90/polePairs)*pi/180),R4*sin((90/polePairs)*pi/180));
mi_setgroup(9);
mi_selectgroup(9);
mi_setblockprop('Air', 1, 0, 0, 0, 9, 0);
mi_clearselected();

% za vazduh u statorksim zlebovima:

R5=statorInnerRadius/2+statorOuterRadius/2;  
if condition1 == 1
mi_addblocklabel(R5*cos(3*angle1*pi/180),R5*sin(3*angle1*pi/180));  % vazduh kod namotaja
mi_selectlabel(R5*cos(3*angle1*pi/180),R5*sin(3*angle1*pi/180));
mi_setgroup(10);
mi_selectgroup(10);
mi_setblockprop('Air', 1, 0, 0, 0, 10, 0);
mi_clearselected();
mi_selectgroup(10);
mi_copyrotate2(0,0,2*angle1,statorSlotsNr-1,4);
mi_clearselected();
else

% statorski namotaji: 

slotsInARow = statorSlotsNr/(6*polePairs);  % broj uzastopnih zlebova koji pripadaju istoj fazi

mi_addblocklabel(R5*cos(angle1*pi/180),R5*sin(angle1*pi/180));  % faza A-
mi_selectlabel(R5*cos(angle1*pi/180),R5*sin(angle1*pi/180));
mi_setgroup(10);
mi_selectgroup(10);
mi_setblockprop('16 AWG', 1, 0, 'A', 0, 10, -wireTurnsPerSlot);
mi_selectgroup(10);
mi_copyrotate2(0, 0, 2*angle1, slotsInARow-1,4);
mi_selectgroup(10);
mi_copyrotate2(0, 0, 12*slotsInARow*angle1, polePairs-1,4);	

mi_addblocklabel(R5*cos(2*angle1*(slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(slotsInARow+0.5)*pi/180));  % faza C
mi_selectlabel(R5*cos(2*angle1*(slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(slotsInARow+0.5)*pi/180));
mi_setgroup(11);
mi_selectgroup(11);
mi_setblockprop('16 AWG', 1, 0, 'C', 0, 11, wireTurnsPerSlot);
mi_selectgroup(11);
mi_copyrotate2(0, 0, 2*angle1, slotsInARow-1,4);
mi_selectgroup(11);
mi_copyrotate2(0, 0, 12*slotsInARow*angle1, polePairs-1,4);	

mi_addblocklabel(R5*cos(2*angle1*(2*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(2*slotsInARow+0.5)*pi/180));  % faza B-
mi_selectlabel(R5*cos(2*angle1*(2*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(2*slotsInARow+0.5)*pi/180));
mi_setgroup(12);
mi_selectgroup(12);
mi_setblockprop('16 AWG', 1, 0, 'B', 0, 12, -wireTurnsPerSlot);
mi_selectgroup(12);
mi_copyrotate2(0, 0, 2*angle1, slotsInARow-1,4);
mi_selectgroup(12);
mi_copyrotate2(0, 0, 12*slotsInARow*angle1, polePairs-1,4);	

mi_addblocklabel(R5*cos(2*angle1*(3*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(3*slotsInARow+0.5)*pi/180));  % faza A
mi_selectlabel(R5*cos(2*angle1*(3*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(3*slotsInARow+0.5)*pi/180));
mi_setgroup(13);
mi_selectgroup(13);
mi_setblockprop('16 AWG', 1, 0, 'A', 0, 13, wireTurnsPerSlot);
mi_selectgroup(13);
mi_copyrotate2(0, 0, 2*angle1, slotsInARow-1,4);
mi_selectgroup(13);
mi_copyrotate2(0, 0, 12*slotsInARow*angle1, polePairs-1,4);

mi_addblocklabel(R5*cos(2*angle1*(4*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(4*slotsInARow+0.5)*pi/180));  % faza C-
mi_selectlabel(R5*cos(2*angle1*(4*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(4*slotsInARow+0.5)*pi/180));
mi_setgroup(14);
mi_selectgroup(14);
mi_setblockprop('16 AWG', 1, 0, 'C', 0, 14, -wireTurnsPerSlot);
mi_selectgroup(14);
mi_copyrotate2(0, 0, 2*angle1, slotsInARow-1,4);
mi_selectgroup(14);
mi_copyrotate2(0, 0, 12*slotsInARow*angle1, polePairs-1,4);

mi_addblocklabel(R5*cos(2*angle1*(5*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(5*slotsInARow+0.5)*pi/180));  % faza B-
mi_selectlabel(R5*cos(2*angle1*(5*slotsInARow+0.5)*pi/180),R5*sin(2*angle1*(5*slotsInARow+0.5)*pi/180));
mi_setgroup(15);
mi_selectgroup(15);
mi_setblockprop('16 AWG', 1, 0, 'B', 0, 15, +wireTurnsPerSlot);
mi_selectgroup(15);
mi_copyrotate2(0, 0, 2*angle1, slotsInARow-1,4);
mi_selectgroup(15);
mi_copyrotate2(0, 0, 12*slotsInARow*angle1, polePairs-1,4);
end  
    
R6=statorOuterRadius-1;
mi_addblocklabel(R6*cos(3*angle1*pi/180),R6*sin(3*angle1*pi/180));  % statorsko gvozdje
mi_selectlabel(R6*cos(3*angle1*pi/180),R6*sin(3*angle1*pi/180));
mi_setgroup(16);
mi_selectgroup(16);
mi_setblockprop('M-19 Steel', 1, 0, 0, 0, 16, 0);
mi_clearselected();

mi_selectarcsegment(0,statorOuterRadius);
mi_selectarcsegment(0,-statorOuterRadius);
mi_setarcsegmentprop(1,'NoNormalFluxAllowed',0,17);  % granicni uslov za ivice masine (No Normal Flux Allowed)
mi_clearselected();

mi_selectarcsegment(0,rotorInnerRadius);
mi_selectarcsegment(0,-rotorInnerRadius);
mi_setarcsegmentprop(1,'NoNormalFluxAllowed',0,18);  % granicni uslov za ivice masine 
mi_clearselected();

mi_zoomnatural();










