function [t1] = Proracunmomenta(Width,Heigth)
%{
- Ova skripta sluzi za proracun momenta masine. Poziva se gotov model masine
u Femm4.2 softveru uz pomoc kojeg se vrsi proracun.
- F-ji se prosledjuju vrednosti sirine i visine vrha zupca motora, a f-ja
vraca vektor korisnog momenta.  
- Kako bi se pokrenule simulacije, neophodno je formirati file u odgovarjucem
direktorijumu - u ovom slucaju nazvan je Modelmasine i moze se obrisati po
zavrsetku proracuna. 

S. Subotic
%}


% Ulazni podaci:

alpha = 20;    % ukupni pomeraj rotora u stepenima
nrSteps = 50;  % broj koraka simulacije

dcTorque = zeros(1,nrSteps);  % inicijalizacija vektora za moment
dtheta = alpha/nrSteps;  % elementarni ugaoni pomeraj 
theta = 0;

% prikaz progresa (rotacija rotora za pojedincane topologije)
%wb = waitbar(0,sprintf('Working... %i%% (%i/%i)',0,0,nrSteps),...  % prikaz napretka
%    'Name',sprintf('Progress (%ideg)',alpha));

% Proracun momenta motora:

for i=1:nrSteps
    Redukovanmodel(Width,Heigth,theta,2);  % poziva se redukovan model masine sa namotajima u statorskim zlebovima
    mi_saveas('Modelmasine.fem');  % memorisanje Femm modela 
    mi_modifyboundprop('Anti-periodic Air Gap',10,theta); % vestacko pomeranje rotora
    mi_analyze(1);    % analiza u Femm-u uz minimiziran prikaz
    mi_loadsolution;  % ucitavanje 
    dcTorque(i) = mo_gapintegral('Anti-periodic Air Gap',0);  % femm f-ja za proracun momenta; 0 za DC Torque                               
    theta = theta + dtheta;  % pomeranje ugla rotora za elementarni ugaoni pomeraj
    %waitbar(i/nrSteps,wb,sprintf('Working... %i%% (%i/%i)',fix(100*i/nrSteps),i,nrSteps));  %  azuriranje napretka                                
end
%close(wb); % zatvaranje prozorcica koji prikazuje napredak

k=2;  % za prikaz k perioda momenta
t1=dcTorque;
for i=1:k-1
    t1=[t1,dcTorque]; 
end

%figure(1);  % prikaz talasnog oblika momenta 
%hold on;
%plot(linspace(0,k*alpha,k*nrSteps),t1);
%xlim([0,k*alpha]);

mo_close;